@@ -11,6 +11,7 @@
 #include <QImage>
 #include <QStandardPaths>
 #include <QThread>
+#include <QSet>
 
 #include <KLocalizedString>
 
@@ -46,6 +47,7 @@ public:
     int m_activePageIndex = -1;
     int m_idCounter = 0;
     const QString m_defaultFileName;
+    QSet<int> m_nonSavedPages;
 };
 
 DocumentModelPrivate::DocumentModelPrivate()
@@ -87,6 +89,11 @@ bool DocumentModel::changed() const
     return d->m_changed;
 }
 
+bool DocumentModel::isReady() const
+{
+    return d->m_nonSavedPages.isEmpty();
+}
+
 int DocumentModel::activePageIndex() const
 {
     return d->m_activePageIndex;
@@ -146,7 +153,13 @@ void DocumentModel::addImage(const QImage &image)
 {
     const double aspectRatio = static_cast<double>(image.height())/image.width();
     beginInsertRows(QModelIndex(), d->m_pages.count(), d->m_pages.count());
-    const PreviewPageProperties newPage = {aspectRatio, 500, static_cast<int>(500 * aspectRatio), d->m_idCounter++, false};
+    const PreviewPageProperties newPage = {aspectRatio, 500, static_cast<int>(500 * aspectRatio), d->m_idCounter, false};
+    const int oldSize = d->m_nonSavedPages.size();
+    d->m_nonSavedPages.insert(d->m_idCounter);
+    if (oldSize == 0 && d->m_nonSavedPages.size() > 0) {
+        Q_EMIT isReadyChanged(false);
+    }
+    d->m_idCounter++;
     qCDebug(SKANPAGE_LOG) << "Inserting new page into model:" << newPage;
     d->m_details.append(newPage);
     d->m_pages.append({nullptr, QPageSize(), 0});
@@ -176,6 +189,10 @@ void DocumentModel::updatePageInModel(const int pageID, const SkanpageUtils::Pag
     d->m_pages[pageIndex].temporaryFile = page.temporaryFile;
     d->m_pages[pageIndex].pageSize = page.pageSize;
     d->m_details[pageIndex].isSaved = true;
+    d->m_nonSavedPages.remove(pageID);
+    if (d->m_nonSavedPages.isEmpty()) {
+        Q_EMIT isReadyChanged(true);
+    }
     Q_EMIT dataChanged(index(pageIndex, 0), index(pageIndex, 0), {ImageUrlRole, IsSavedRole});
 
     if (!d->m_changed) {
@@ -251,6 +268,30 @@ void DocumentModel::rotateImage(int row, RotateOption rotate)
     Q_EMIT dataChanged(index(row, 0), index(row, 0), {RotationAngleRole});
 }
 
+void DocumentModel::flipPages(FlipPagesOption flip)
+{
+    int start = 0;
+    int increment = 1;
+    if (flip == FlipPagesOption::FlipEven) {
+        start = 1;
+    }
+    if (flip == FlipPagesOption::FlipEven || flip == FlipPagesOption::FlipOdd) {
+        increment = 2;
+    }
+    for (int i = start; i < d->m_pages.count(); i+=increment) {
+        int rotationAngle = d->m_pages.at(i).rotationAngle;
+        rotationAngle += 180;
+        if (rotationAngle < 0) {
+            rotationAngle = rotationAngle + 360;
+        } else if (rotationAngle >= 360) {
+            rotationAngle = rotationAngle - 360;
+        }
+        d->m_pages[i].rotationAngle = rotationAngle;
+    }
+    Q_EMIT activePageChanged();
+    Q_EMIT dataChanged(index(0, 0), index(d->m_pages.count()-1, 0), {RotationAngleRole});
+}
+
 void DocumentModel::reorderPages(ReorderOption reorder)
 {
     Q_EMIT layoutAboutToBeChanged();
